'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var React = require('react');
var core = require('@react-pdf-viewer/core');

var ZoomInIcon = function () {
    return (React.createElement(core.Icon, { size: 16 },
        React.createElement("path", { d: "M10.5,0.499c5.523,0,10,4.477,10,10s-4.477,10-10,10s-10-4.477-10-10S4.977,0.499,10.5,0.499z\n                M23.5,23.499\n                l-5.929-5.929\n                M5.5,10.499h10\n                M10.5,5.499v10" })));
};

var ZoomOutIcon = function () {
    return (React.createElement(core.Icon, { size: 16 },
        React.createElement("path", { d: "M10.5,0.499c5.523,0,10,4.477,10,10s-4.477,10-10,10s-10-4.477-10-10S4.977,0.499,10.5,0.499z\n                M23.5,23.499\n                l-5.929-5.929\n                M5.5,10.499h10" })));
};

/*! *****************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */

var __assign = function() {
    __assign = Object.assign || function __assign(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};

var useZoom = function (store) {
    var _a = React.useState(store.get('scale') || 0), scale = _a[0], setScale = _a[1];
    var handleScaleChanged = function (currentScale) {
        setScale(currentScale);
    };
    React.useEffect(function () {
        store.subscribe('scale', handleScaleChanged);
        return function () {
            store.unsubscribe('scale', handleScaleChanged);
        };
    }, []);
    return { scale: scale };
};

var CurrentScale = function (_a) {
    var children = _a.children, store = _a.store;
    var scale = useZoom(store).scale;
    var defaultChildren = function (props) { return React.createElement(React.Fragment, null, Math.round(props.scale * 100) + "%"); };
    var render = children || defaultChildren;
    return render({ scale: scale });
};

var LEVELS = [0.5, 0.75, 1, 1.25, 1.5, 2, 3, 4];
var PORTAL_OFFSET = { left: 0, top: 8 };
var ZoomPopover = function (_a) {
    var scale = _a.scale, onZoom = _a.onZoom;
    var l10n = React.useContext(core.LocalizationContext);
    var getSpcialLevelLabel = function (level) {
        switch (level) {
            case core.SpecialZoomLevel.ActualSize:
                return l10n && l10n.zoom ? l10n.zoom.actualSize : 'Actual size';
            case core.SpecialZoomLevel.PageFit:
                return l10n && l10n.zoom ? l10n.zoom.pageFit : 'Page fit';
            case core.SpecialZoomLevel.PageWidth:
                return l10n && l10n.zoom ? l10n.zoom.pageWidth : 'Page width';
        }
    };
    var renderTarget = function (toggle) {
        var click = function () { toggle(); };
        return (React.createElement("span", { className: 'rpv-zoom-popover-target', onClick: click },
            React.createElement("span", { className: 'rpv-zoom-popover-target-scale' },
                Math.round(scale * 100),
                "%"),
            React.createElement("span", { className: 'rpv-zoom-popover-target-arrow' })));
    };
    var renderContent = function (toggle) { return (React.createElement(core.Menu, null,
        Object.keys(core.SpecialZoomLevel).map(function (k) {
            var level = k;
            var clickMenuItem = function () { toggle(); onZoom(level); };
            return (React.createElement(core.MenuItem, { key: level, onClick: clickMenuItem }, getSpcialLevelLabel(level)));
        }),
        React.createElement(core.MenuDivider, null),
        LEVELS.map(function (level) {
            var clickMenuItem = function () { toggle(); onZoom(level); };
            return (React.createElement(core.MenuItem, { key: level, onClick: clickMenuItem }, Math.round(level * 100) + "%"));
        }))); };
    return (React.createElement(core.Popover, { position: core.Position.BottomCenter, target: renderTarget, content: renderContent, offset: PORTAL_OFFSET, closeOnClickOutside: true, closeOnEscape: true }));
};

var Zoom = function (_a) {
    var children = _a.children, store = _a.store;
    var scale = useZoom(store).scale;
    var zoomTo = function (newLevel) {
        var zoom = store.get('zoom');
        if (zoom) {
            zoom(newLevel);
        }
    };
    var defaultChildren = function (props) { return React.createElement(ZoomPopover, { scale: props.scale, onZoom: props.onZoom }); };
    var render = children || defaultChildren;
    return render({
        scale: scale,
        onZoom: zoomTo,
    });
};

var TOOLTIP_OFFSET = { left: 0, top: 8 };
var ZoomInButton = function (_a) {
    var onClick = _a.onClick;
    var l10n = React.useContext(core.LocalizationContext);
    var label = l10n && l10n.zoom ? l10n.zoom.zoomIn : 'Zoom in';
    return (React.createElement(core.Tooltip, { position: core.Position.BottomCenter, target: React.createElement(core.Button, { onClick: onClick },
            React.createElement(ZoomInIcon, null)), content: function () { return label; }, offset: TOOLTIP_OFFSET }));
};

var LEVELS$1 = [
    0.1,
    0.2,
    0.3,
    0.4,
    0.5,
    0.6,
    0.7,
    0.8,
    0.9,
    1,
    1.1,
    1.3,
    1.5,
    1.7,
    1.9,
    2.1,
    2.4,
    2.7,
    3.0,
    3.3,
    3.7,
    4.1,
    4.6,
    5.1,
    5.7,
    6.3,
    7.0,
    7.7,
    8.5,
    9.4,
    10,
];
var increase = function (currentLevel) {
    var found = LEVELS$1.find(function (item) { return item > currentLevel; });
    return found || currentLevel;
};
var decrease = function (currentLevel) {
    var found = LEVELS$1.findIndex(function (item) { return item >= currentLevel; });
    return found === -1 || found === 0 ? currentLevel : LEVELS$1[found - 1];
};

var ZoomIn = function (_a) {
    var children = _a.children, store = _a.store;
    var scale = useZoom(store).scale;
    var zoomIn = function () {
        var zoom = store.get('zoom');
        if (zoom) {
            var newLevel = increase(scale);
            zoom(newLevel);
        }
    };
    var defaultChildren = function (props) { return React.createElement(ZoomInButton, { onClick: props.onClick }); };
    var render = children || defaultChildren;
    return render({
        onClick: zoomIn,
    });
};

var TOOLTIP_OFFSET$1 = { left: 0, top: 8 };
var ZoomOutButton = function (_a) {
    var onClick = _a.onClick;
    var l10n = React.useContext(core.LocalizationContext);
    var label = l10n && l10n.zoom ? l10n.zoom.zoomOut : 'Zoom out';
    return (React.createElement(core.Tooltip, { position: core.Position.BottomCenter, target: React.createElement(core.Button, { onClick: onClick },
            React.createElement(ZoomOutIcon, null)), content: function () { return label; }, offset: TOOLTIP_OFFSET$1 }));
};

var ZoomOut = function (_a) {
    var children = _a.children, store = _a.store;
    var scale = useZoom(store).scale;
    var zoomIn = function () {
        var zoom = store.get('zoom');
        if (zoom) {
            var newLevel = decrease(scale);
            zoom(newLevel);
        }
    };
    var defaultChildren = function (props) { return React.createElement(ZoomOutButton, { onClick: props.onClick }); };
    var render = children || defaultChildren;
    return render({
        onClick: zoomIn,
    });
};

var zoomPlugin = function () {
    var store = React.useMemo(function () { return core.createStore({}); }, []);
    var CurrentScaleDecorator = function (props) { return (React.createElement(CurrentScale, __assign({}, props, { store: store }))); };
    var ZoomInDecorator = function (props) { return (React.createElement(ZoomIn, __assign({}, props, { store: store }))); };
    var ZoomInButtonDecorator = function () { return (React.createElement(ZoomInDecorator, null, function (props) { return React.createElement(ZoomInButton, __assign({}, props)); })); };
    var ZoomOutDecorator = function (props) { return (React.createElement(ZoomOut, __assign({}, props, { store: store }))); };
    var ZoomOutButtonDecorator = function () { return (React.createElement(ZoomOutDecorator, null, function (props) { return React.createElement(ZoomOutButton, __assign({}, props)); })); };
    var ZoomDecorator = function (props) { return React.createElement(Zoom, __assign({}, props, { store: store })); };
    var ZoomPopoverDecorator = function () { return (React.createElement(ZoomDecorator, null, function (props) { return React.createElement(ZoomPopover, __assign({}, props)); })); };
    return {
        install: function (pluginFunctions) {
            store.update('zoom', pluginFunctions.zoom);
        },
        onViewerStateChange: function (viewerState) {
            store.update('scale', viewerState.scale);
            return viewerState;
        },
        CurrentScale: CurrentScaleDecorator,
        ZoomIn: ZoomInDecorator,
        ZoomInButton: ZoomInButtonDecorator,
        ZoomOut: ZoomOutDecorator,
        ZoomOutButton: ZoomOutButtonDecorator,
        Zoom: ZoomDecorator,
        ZoomPopover: ZoomPopoverDecorator,
    };
};

exports.ZoomInIcon = ZoomInIcon;
exports.ZoomOutIcon = ZoomOutIcon;
exports.zoomPlugin = zoomPlugin;
